<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Axel Kirch <axel@globeglotter.com>
 * @author MaWi <drmaxxis@gmail.com>
 * @author lp <spam@lukpopp.ch>
 * @author Martin <martin@andev.de>
 * @author F. Mueller-Donath <j.felix@mueller-donath.de>
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Christof <gagi@fin.de>
 * @author Anika Henke <anika@selfthinker.org>
 * @author Esther Brunner <esther@kaffeehaus.ch>
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 * @author Alexander Fischer <tbanus@os-forge.net>
 * @author Juergen Schwarzer <jschwarzer@freenet.de>
 * @author Marcel Metz <marcel_metz@gmx.de>
 * @author Matthias Schulte <dokuwiki@lupo49.de>
 * @author Christian Wichmann <nospam@zone0.de>
 * @author Pierre Corell <info@joomla-praxis.de>
 * @author Frank Loizzi <contact@software.bacal.de>
 * @author Volker Bödker <volker@boedker.de>
 * @author Janosch <janosch@moinzen.de>
 * @author rnck <dokuwiki@rnck.de>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Diese Seite bearbeiten';
$lang['btn_source']            = 'Quelltext anzeigen';
$lang['btn_show']              = 'Seite anzeigen';
$lang['btn_create']            = 'Seite anlegen';
$lang['btn_search']            = 'Suchen';
$lang['btn_save']              = 'Speichern';
$lang['btn_preview']           = 'Vorschau';
$lang['btn_top']               = 'Nach oben';
$lang['btn_newer']             = '<< jüngere Änderungen';
$lang['btn_older']             = 'ältere Änderungen >>';
$lang['btn_revs']              = 'Ältere Versionen';
$lang['btn_recent']            = 'Letzte Änderungen';
$lang['btn_upload']            = 'Hochladen';
$lang['btn_cancel']            = 'Abbrechen';
$lang['btn_index']             = 'Übersicht';
$lang['btn_secedit']           = 'Bearbeiten';
$lang['btn_login']             = 'Anmelden';
$lang['btn_logout']            = 'Abmelden';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Aktualisieren';
$lang['btn_delete']            = 'Löschen';
$lang['btn_back']              = 'Zurück';
$lang['btn_backlink']          = 'Links hierher';
$lang['btn_subscribe']         = 'Aboverwaltung';
$lang['btn_profile']           = 'Benutzerprofil';
$lang['btn_reset']             = 'Zurücksetzen';
$lang['btn_resendpwd']         = 'Neues Passwort festlegen';
$lang['btn_draft']             = 'Entwurf bearbeiten';
$lang['btn_recover']           = 'Entwurf wiederherstellen';
$lang['btn_draftdel']          = 'Entwurf löschen';
$lang['btn_revert']            = 'Wiederherstellen';
$lang['btn_register']          = 'Registrieren';
$lang['btn_apply']             = 'Übernehmen';
$lang['btn_media']             = 'Medien-Manager';
$lang['btn_deleteuser']        = 'Benutzerprofil löschen';
$lang['btn_img_backto']        = 'Zurück zu %s';
$lang['btn_mediaManager']      = 'Im Medien-Manager anzeigen';
$lang['loggedinas']            = 'Angemeldet als:';
$lang['user']                  = 'Benutzername';
$lang['pass']                  = 'Passwort';
$lang['newpass']               = 'Neues Passwort';
$lang['oldpass']               = 'Bestätigen (Altes Passwort)';
$lang['passchk']               = 'Passwort erneut eingeben';
$lang['remember']              = 'Angemeldet bleiben';
$lang['fullname']              = 'Voller Name';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Benutzerprofil';
$lang['badlogin']              = 'Benutzername oder Passwort sind falsch.';
$lang['badpassconfirm']        = 'Das Passwort war falsch.';
$lang['minoredit']             = 'Kleine Änderung';
$lang['draftdate']             = 'Entwurf automatisch gesichert am';
$lang['nosecedit']             = 'Diese Seite wurde inzwischen geändert. Weil deshalb ein oder mehrere Abschnitte veraltet sind, wurde die Seite komplett neu geladen.';
$lang['searchcreatepage']      = 'Falls der gesuchte Begriff nicht gefunden wurde, kannst du die nach deiner Anfrage benannte Seite %s umgehend neu anlegen.';
$lang['search_fullresults']    = 'Volltextergebnisse';
$lang['js']['search_toggle_tools'] = 'Suchwerkzeuge umschalten';
$lang['js']['willexpire']      = 'Die Sperre zur Bearbeitung dieser Seite läuft in einer Minute ab.\nUm Bearbeitungskonflikte zu vermeiden, solltest du sie durch einen Klick auf den Vorschau-Knopf verlängern.';
$lang['js']['notsavedyet']     = 'Nicht gespeicherte Änderungen gehen verloren!';
$lang['js']['searchmedia']     = 'Suche nach Dateien';
$lang['js']['keepopen']        = 'Fenster nach Auswahl nicht schließen';
$lang['js']['hidedetails']     = 'Details ausblenden';
$lang['js']['mediatitle']      = 'Link-Eigenschaften';
$lang['js']['mediadisplay']    = 'Linktyp';
$lang['js']['mediaalign']      = 'Ausrichtung';
$lang['js']['mediasize']       = 'Bildgröße';
$lang['js']['mediatarget']     = 'Linkziel';
$lang['js']['mediaclose']      = 'Schließen';
$lang['js']['mediainsert']     = 'Einfügen';
$lang['js']['mediadisplayimg'] = 'Bild anzeigen';
$lang['js']['mediadisplaylnk'] = 'Nur den Link anzeigen';
$lang['js']['mediasmall']      = 'Bild in kleiner Auflösung';
$lang['js']['mediamedium']     = 'Bild in mittlerer Auflösung';
$lang['js']['medialarge']      = 'Bild in hoher Auflösung';
$lang['js']['mediaoriginal']   = 'Originalauflösung';
$lang['js']['medialnk']        = 'Link zur Detailseite';
$lang['js']['mediadirect']     = 'Direkter Link zum Original';
$lang['js']['medianolnk']      = 'Kein Link';
$lang['js']['medianolink']     = 'Bild nicht verlinken';
$lang['js']['medialeft']       = 'Bild linksbündig ausrichten.';
$lang['js']['mediaright']      = 'Bild rechtsbündig ausrichten.';
$lang['js']['mediacenter']     = 'Bild horizontal zentriert ausrichten';
$lang['js']['medianoalign']    = 'Bild ohne bestimmte Ausrichtung lassen';
$lang['js']['nosmblinks']      = 'Das Verlinken von Windows-Freigaben funktioniert nur im Microsoft Internet-Explorer.\nDer Link kann jedoch zum Einfügen kopiert werden.';
$lang['js']['linkwiz']         = 'Link-Assistent';
$lang['js']['linkto']          = 'Link zu:';
$lang['js']['del_confirm']     = 'Die ausgewählten Dateien wirklich löschen?';
$lang['js']['restore_confirm'] = 'Wirklich diese Version wiederherstellen?';
$lang['js']['media_diff']      = 'Unterschiede anzeigen:';
$lang['js']['media_diff_both'] = 'Nebeneinander';
$lang['js']['media_diff_opacity'] = 'Überblenden';
$lang['js']['media_diff_portions'] = 'Übergang';
$lang['js']['media_select']    = 'Dateien auswählen…';
$lang['js']['media_upload_btn'] = 'Hochladen';
$lang['js']['media_done_btn']  = 'Fertig';
$lang['js']['media_drop']      = 'Dateien hier hinziehen um sie hochzuladen';
$lang['js']['media_cancel']    = 'Entfernen';
$lang['js']['media_overwrt']   = 'Existierende Dateien überschreiben';
$lang['search_exact_match']    = 'Genaue Treffer';
$lang['search_starts_with']    = 'Beginnt mit';
$lang['search_ends_with']      = 'Endet mit';
$lang['search_contains']       = 'Enthält';
$lang['search_custom_match']   = 'Angepasst ';
$lang['search_any_ns']         = 'Alle Namensräume';
$lang['search_any_time']       = 'Jederzeit';
$lang['search_past_7_days']    = 'Letzte Woche';
$lang['search_past_month']     = 'Letzter Monat';
$lang['search_past_year']      = 'Letztes Jahr';
$lang['search_sort_by_hits']   = 'Sortiere nach Treffer';
$lang['search_sort_by_mtime']  = 'Sortiere nach letzter Änderung';
$lang['regmissing']            = 'Alle Felder müssen ausgefüllt werden';
$lang['reguexists']            = 'Der Benutzername existiert leider schon.';
$lang['regsuccess']            = 'Der neue Benutzer wurde angelegt und das Passwort per E-Mail versandt.';
$lang['regsuccess2']           = 'Der neue Benutzer wurde angelegt.';
$lang['regfail']               = 'Der Benutzer konnte nicht erstellt werden.';
$lang['regmailfail']           = 'Offenbar ist ein Fehler beim Versenden der Passwortmail aufgetreten. Bitte wende dich an den Wiki-Admin.';
$lang['regbadmail']            = 'Die angegebene Mail-Adresse scheint ungültig zu sein. Falls dies ein Fehler ist, wende dich bitte an den Wiki-Admin.';
$lang['regbadpass']            = 'Die beiden eingegeben Passwörter stimmen nicht überein. Bitte versuche es noch einmal.';
$lang['regpwmail']             = 'Ihr DokuWiki-Passwort';
$lang['reghere']               = 'Du hast noch keinen Zugang? Hier registrieren';
$lang['profna']                = 'Änderung des Benutzerprofils in diesem Wiki nicht möglich.';
$lang['profnochange']          = 'Keine Änderungen, nichts zu tun.';
$lang['profnoempty']           = 'Es muss ein Name oder eine E-Mail Adresse angegeben werden.';
$lang['profchanged']           = 'Benutzerprofil erfolgreich geändert.';
$lang['profnodelete']          = 'Dieses Wiki unterstützt nicht das Löschen von Benutzern.';
$lang['profdeleteuser']        = 'Benutzerprofil löschen';
$lang['profdeleted']           = 'Dein Benutzerprofil wurde im Wiki gelöscht.';
$lang['profconfdelete']        = 'Ich möchte mein Benutzerprofil löschen.<br/> Diese Aktion ist nicht umkehrbar.';
$lang['profconfdeletemissing'] = 'Bestätigungs-Checkbox wurde nicht angehakt.';
$lang['proffail']              = 'Das Benutzerprofil wurde nicht aktualisiert.';
$lang['pwdforget']             = 'Passwort vergessen? Fordere ein neues an';
$lang['resendna']              = 'Passwörter versenden ist in diesem Wiki nicht möglich.';
$lang['resendpwd']             = 'Neues Passwort setzen für';
$lang['resendpwdmissing']      = 'Es tut mir leid, aber du musst alle Felder ausfüllen.';
$lang['resendpwdnouser']       = 'Es tut mir leid, aber der Benutzer existiert nicht in unserer Datenbank.';
$lang['resendpwdbadauth']      = 'Es tut mir leid, aber dieser Authentifizierungscode ist ungültig. Stelle sicher, dass du den kompletten Bestätigungslink verwendet haben.';
$lang['resendpwdconfirm']      = 'Ein Bestätigungslink wurde per E-Mail versandt.';
$lang['resendpwdsuccess']      = 'Dein neues Passwort wurde per E-Mail versandt.';
$lang['license']               = 'Falls nicht anders bezeichnet, ist der Inhalt dieses Wikis unter der folgenden Lizenz veröffentlicht:';
$lang['licenseok']             = 'Hinweis: Durch das Bearbeiten dieser Seite gibst du dein Einverständnis, dass dein Inhalt unter der folgenden Lizenz veröffentlicht wird:';
$lang['searchmedia']           = 'Suche nach Datei:';
$lang['searchmedia_in']        = 'Suche in %s';
$lang['txt_upload']            = 'Datei zum Hochladen auswählen:';
$lang['txt_filename']          = 'Hochladen als (optional):';
$lang['txt_overwrt']           = 'Bestehende Datei überschreiben';
$lang['maxuploadsize']         = 'Max. %s pro Datei-Upload.';
$lang['allowedmime']           = 'Liste der erlaubten Dateiendungen';
$lang['lockedby']              = 'Momentan gesperrt von:';
$lang['lockexpire']            = 'Sperre läuft ab am:';
$lang['rssfailed']             = 'Es ist ein Fehler beim Laden des Feeds aufgetreten: ';
$lang['nothingfound']          = 'Nichts gefunden.';
$lang['mediaselect']           = 'Dateiauswahl';
$lang['uploadsucc']            = 'Datei wurde erfolgreich hochgeladen';
$lang['uploadfail']            = 'Hochladen fehlgeschlagen. Keine Berechtigung?';
$lang['uploadwrong']           = 'Hochladen verweigert. Diese Dateiendung ist nicht erlaubt.';
$lang['uploadexist']           = 'Datei existiert bereits. Keine Änderungen vorgenommen.';
$lang['uploadbadcontent']      = 'Die hochgeladenen Daten stimmen nicht mit der Dateiendung %s überein.';
$lang['uploadspam']            = 'Hochladen verweigert: Treffer auf der Spamliste.';
$lang['uploadxss']             = 'Hochladen verweigert: Daten scheinen Schadcode zu enthalten.';
$lang['uploadsize']            = 'Die hochgeladene Datei war zu groß. (max. %s)';
$lang['deletesucc']            = 'Die Datei "%s" wurde gelöscht.';
$lang['deletefail']            = '"%s" konnte nicht gelöscht werden. Keine Berechtigung?.';
$lang['mediainuse']            = 'Die Datei "%s" wurde nicht gelöscht. Sie wird noch verwendet.';
$lang['namespaces']            = 'Namensräume';
$lang['mediafiles']            = 'Vorhandene Dateien in';
$lang['accessdenied']          = 'Du hast keinen Zugriff auf diese Seite';
$lang['mediausage']            = 'Syntax zum Verwenden dieser Datei:';
$lang['mediaview']             = 'Originaldatei öffnen';
$lang['mediaroot']             = 'Wurzel';
$lang['mediaupload']           = 'Lade hier eine Datei in den momentanen Namensraum hoch. Um Unterordner zu erstellen, stelle diese dem Dateinamen durch Doppelpunkt getrennt voran, nachdem Du die Datei ausgewählt hast.';
$lang['mediaextchange']        = 'Dateiendung vom .%s nach .%s geändert!';
$lang['reference']             = 'Verwendung von';
$lang['ref_inuse']             = 'Diese Datei kann nicht gelöscht werden, da sie noch von folgenden Seiten benutzt wird:';
$lang['ref_hidden']            = 'Einige Verweise sind auf Seiten, für die du keine Leseberechtigung hast.';
$lang['hits']                  = 'Treffer';
$lang['quickhits']             = 'Passende Seitennamen';
$lang['toc']                   = 'Inhaltsverzeichnis';
$lang['current']               = 'aktuell';
$lang['yours']                 = 'Deine Version';
$lang['diff']                  = 'Zeige Unterschiede zu aktueller Version';
$lang['diff2']                 = 'Zeige Unterschiede der ausgewählten Versionen';
$lang['difflink']              = 'Link zu der Vergleichsansicht';
$lang['diff_type']             = 'Unterschiede anzeigen:';
$lang['diff_inline']           = 'Inline';
$lang['diff_side']             = 'Nebeneinander';
$lang['diffprevrev']           = 'Vorherige Überarbeitung';
$lang['diffnextrev']           = 'Nächste Überarbeitung';
$lang['difflastrev']           = 'Letzte Überarbeitung';
$lang['diffbothprevrev']       = 'Beide Seiten, vorherige Überarbeitung';
$lang['diffbothnextrev']       = 'Beide Seiten, nächste Überarbeitung';
$lang['line']                  = 'Zeile';
$lang['breadcrumb']            = 'Zuletzt angesehen:';
$lang['youarehere']            = 'Du befindest dich hier:';
$lang['lastmod']               = 'Zuletzt geändert:';
$lang['by']                    = 'von';
$lang['deleted']               = 'gelöscht';
$lang['created']               = 'angelegt';
$lang['restored']              = 'alte Version wiederhergestellt (%s)';
$lang['external_edit']         = 'Externe Bearbeitung';
$lang['summary']               = 'Zusammenfassung';
$lang['noflash']               = 'Das <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> wird benötigt, um diesen Inhalt anzuzeigen.';
$lang['download']              = 'Schnipsel herunterladen';
$lang['tools']                 = 'Werkzeuge';
$lang['user_tools']            = 'Benutzer-Werkzeuge';
$lang['site_tools']            = 'Webseiten-Werkzeuge';
$lang['page_tools']            = 'Seiten-Werkzeuge';
$lang['skip_to_content']       = 'zum Inhalt springen';
$lang['sidebar']               = 'Seitenleiste';
$lang['mail_newpage']          = 'Neue Seite:';
$lang['mail_changed']          = 'Seite geändert:';
$lang['mail_subscribe_list']   = 'Geänderte Seiten im Namensraum:';
$lang['mail_new_user']         = 'Neuer Benutzer:';
$lang['mail_upload']           = 'Datei hochgeladen:';
$lang['changes_type']          = 'Änderungen anzeigen von';
$lang['pages_changes']         = 'Seiten';
$lang['media_changes']         = 'Mediendateien';
$lang['both_changes']          = 'Beides, Seiten- und Mediendateien';
$lang['qb_bold']               = 'Fetter Text';
$lang['qb_italic']             = 'Kursiver Text';
$lang['qb_underl']             = 'Unterstrichener Text';
$lang['qb_code']               = 'Code Text';
$lang['qb_strike']             = 'Durchgestrichener Text';
$lang['qb_h1']                 = 'Level 1 Überschrift';
$lang['qb_h2']                 = 'Level 2 Überschrift';
$lang['qb_h3']                 = 'Level 3 Überschrift';
$lang['qb_h4']                 = 'Level 4 Überschrift';
$lang['qb_h5']                 = 'Level 5 Überschrift';
$lang['qb_h']                  = 'Überschrift';
$lang['qb_hs']                 = 'Wähle eine Überschrift';
$lang['qb_hplus']              = 'Überschrift eine Ebene höher';
$lang['qb_hminus']             = 'Überschrift eine Ebene runter';
$lang['qb_hequal']             = 'Überschrift auf selber Ebene';
$lang['qb_link']               = 'Interner Link';
$lang['qb_extlink']            = 'Externer Link';
$lang['qb_hr']                 = 'Horizontale Linie';
$lang['qb_ol']                 = 'Nummerierter Listenpunkt';
$lang['qb_ul']                 = 'Listenpunkt';
$lang['qb_media']              = 'Bilder und andere Dateien hinzufügen';
$lang['qb_sig']                = 'Unterschrift einfügen';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Sonderzeichen';
$lang['upperns']               = 'Gehe zum übergeordneten Namensraum';
$lang['metaedit']              = 'Metadaten bearbeiten';
$lang['metasaveerr']           = 'Die Metadaten konnten nicht gesichert werden';
$lang['metasaveok']            = 'Metadaten gesichert';
$lang['img_title']             = 'Titel:';
$lang['img_caption']           = 'Bildunterschrift:';
$lang['img_date']              = 'Datum:';
$lang['img_fname']             = 'Dateiname:';
$lang['img_fsize']             = 'Größe:';
$lang['img_artist']            = 'Fotograf:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Format:';
$lang['img_camera']            = 'Kamera:';
$lang['img_keywords']          = 'Schlagwörter:';
$lang['img_width']             = 'Breite:';
$lang['img_height']            = 'Höhe:';
$lang['subscr_subscribe_success'] = 'Die Seite %s wurde zur Abonnementliste von %s hinzugefügt';
$lang['subscr_subscribe_error'] = 'Fehler beim Hinzufügen von %s zur Abonnementliste von %s';
$lang['subscr_subscribe_noaddress'] = 'In deinem Account ist keine E-Mail-Adresse hinterlegt. Dadurch kann die Seite nicht abonniert werden';
$lang['subscr_unsubscribe_success'] = 'Die Seite %s wurde von der Abonnementliste von %s entfernt';
$lang['subscr_unsubscribe_error'] = 'Fehler beim Entfernen von %s von der Abonnementliste von %s';
$lang['subscr_already_subscribed'] = '%s ist bereits auf der Abonnementliste von %s';
$lang['subscr_not_subscribed'] = '%s ist nicht auf der Abonnementliste von %s';
$lang['subscr_m_not_subscribed'] = 'Du hast kein Abonnement von dieser Seite oder dem Namensraum.';
$lang['subscr_m_new_header']   = 'Abonnementen hinzufügen';
$lang['subscr_m_current_header'] = 'Aktive Abonnements';
$lang['subscr_m_unsubscribe']  = 'Abbestellen';
$lang['subscr_m_subscribe']    = 'Abonnieren';
$lang['subscr_m_receive']      = 'Erhalten';
$lang['subscr_style_every']    = 'E-Mail bei jeder Änderung';
$lang['subscr_style_digest']   = 'E-Mail mit zusammengefasster Übersicht der Seitenänderungen (alle %.2f Tage)';
$lang['subscr_style_list']     = 'Auflistung aller geänderten Seiten seit der letzten E-Mail (alle %.2f Tage)';
$lang['authtempfail']          = 'Benutzerüberprüfung momentan nicht möglich. Falls das Problem andauert, wende dich an den Admin.';
$lang['i_chooselang']          = 'Wähle deine Sprache';
$lang['i_installer']           = 'DokuWiki-Installation';
$lang['i_wikiname']            = 'Wiki-Name';
$lang['i_enableacl']           = 'Zugriffskontrolle (ACL) aktivieren (empfohlen)';
$lang['i_superuser']           = 'Benutzername des Administrators';
$lang['i_problems']            = 'Das Installationsprogramm hat unten aufgeführte Probleme festgestellt, die zunächst behoben werden müssen, bevor du mit der Installation fortfahren kannst.';
$lang['i_modified']            = 'Aus Sicherheitsgründen arbeitet dieses Skript nur mit einer neuen bzw. nicht modifizierten DokuWiki-Installation. Du solltest entweder alle Dateien noch einmal frisch installieren oder die <a href="https://www.dokuwiki.org/install">Dokuwiki-Installationsanleitung</a> konsultieren.';
$lang['i_funcna']              = 'Die PHP-Funktion <code>%s</code> ist nicht verfügbar. Unter Umständen wurde sie von deinem Hoster deaktiviert?';
$lang['i_disabled']            = 'Es wurde von deinem Provider deaktiviert.';
$lang['i_funcnmail']           = '<b>Hinweis:</b> Die PHP-Funktion "mail()" ist nicht verfügbar. %s Alternativ kansnt du das <a href="https://www.dokuwiki.org/plugin:smtp">SMTP-Plugin</a> installieren.';
$lang['i_phpver']              = 'Deine PHP-Version <code>%s</code> ist niedriger als die benötigte Version <code>%s</code>. Bitte aktualisiere deine PHP-Installation.';
$lang['i_mbfuncoverload']      = 'mbstring.func_overload muss in php.in deaktiviert werden um DokuWiki auszuführen.';
$lang['i_urandom']             = 'DokuWiki kann keine kryptografisch sicheren Werte für Cookies generieren. Möglicherweise möchtest du die "open_basedir"-Einstellungen in der zutreffenden php.ini auf korrekten Zugriff auf <code>/ dev/urandom</ code> überprüfen.';
$lang['i_permfail']            = '<code>%s</code> ist nicht durch DokuWiki beschreibbar. Du musst die Berechtigungen dieses Ordners ändern!';
$lang['i_confexists']          = '<code>%s</code> existiert bereits';
$lang['i_writeerr']            = '<code>%s</code> konnte nicht erzeugt werden. Du solltest die Verzeichnis-/Datei-Rechte überprüfen und die Datei manuell anlegen.';
$lang['i_badhash']             = 'Unbekannte oder modifizierte dokuwiki.php (Hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - unerlaubter oder leerer Wert';
$lang['i_success']             = 'Die Konfiguration wurde erfolgreich abgeschlossen. Du kannst jetzt die install.php löschen. Dein <a href="doku.php?id=wiki:welcome">neues DokuWiki</a> ist jetzt für dich bereit.';
$lang['i_failure']             = 'Es sind Fehler beim Schreiben der Konfigurationsdateien aufgetreten. Du musst diese von Hand beheben, bevor du dein <a href="doku.php?id=wiki:welcome">neues DokuWiki</a> nutzen kannst.';
$lang['i_policy']              = 'Anfangseinstellungen der Zugriffskontrolle (ACL)';
$lang['i_pol0']                = 'Offenes Wiki (lesen, schreiben und hochladen für alle Benutzer)';
$lang['i_pol1']                = 'Öffentliches Wiki (Lesen für alle, Schreiben und Hochladen nur für registrierte Benutzer)';
$lang['i_pol2']                = 'Geschlossenes Wiki (Lesen, Schreiben und Hochladen nur für registrierte Benutzer)';
$lang['i_allowreg']            = 'Benutzer können sich selbst registrieren';
$lang['i_retry']               = 'Wiederholen';
$lang['i_license']             = 'Bitte wähle die Lizenz aus unter der die Wiki-Inhalte veröffentlicht werden sollen:';
$lang['i_license_none']        = 'Keine Lizenzinformationen anzeigen';
$lang['i_pop_field']           = 'Bitte helfe uns, die DokuWiki-Erfahrung zu verbessern';
$lang['i_pop_label']           = 'Sende einmal im Monat anonyme Nutzungsdaten an die DokuWiki Entwickler';
$lang['recent_global']         = 'Im Moment siehst du die Änderungen im Namensraum <b>%s</b>. Du kannst auch <a href="%s">die Änderungen im gesamten Wiki sehen</a>.';
$lang['years']                 = 'vor %d Jahren';
$lang['months']                = 'vor %d Monaten';
$lang['weeks']                 = 'vor %d Wochen';
$lang['days']                  = 'vor %d Tagen';
$lang['hours']                 = 'vor %d Stunden';
$lang['minutes']               = 'vor %d Minuten';
$lang['seconds']               = 'vor %d Sekunden';
$lang['wordblock']             = 'Deine Bearbeitung wurde nicht gespeichert, da sie gesperrten Text enthielt (Spam).';
$lang['media_uploadtab']       = 'Hochladen';
$lang['media_searchtab']       = 'Suchen';
$lang['media_file']            = 'Datei';
$lang['media_viewtab']         = 'Anzeigen';
$lang['media_edittab']         = 'Bearbeiten';
$lang['media_historytab']      = 'Verlauf';
$lang['media_list_thumbs']     = 'Medien anzeigen als Miniaturansicht';
$lang['media_list_rows']       = 'Medien anzeigen als Listenansicht';
$lang['media_sort_name']       = 'Sortieren nach Name';
$lang['media_sort_date']       = 'Sortieren nach Datum';
$lang['media_namespaces']      = 'Namensraum wählen';
$lang['media_files']           = 'Medien im Namensraum <strong>%s</strong>.';
$lang['media_upload']          = 'In den <strong>%s</strong> Namensraum hochladen.';
$lang['media_search']          = 'Im Namensraum <strong>%s</strong> suchen.';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s in %s';
$lang['media_edit']            = '%s bearbeiten';
$lang['media_history']         = 'Versionen von %s';
$lang['media_meta_edited']     = 'Meta-Informationen bearbeitet';
$lang['media_perm_read']       = 'Du besitzt nicht die notwendigen Berechtigungen um die Datei anzuzeigen.';
$lang['media_perm_upload']     = 'Du besitzt nicht die notwendigen Berechtigungen um Dateien hochzuladen.';
$lang['media_update']          = 'Neue Version hochladen';
$lang['media_restore']         = 'Diese Version wiederherstellen';
$lang['media_acl_warning']     = 'Diese Liste ist möglicherweise nicht vollständig. Versteckte und durch ACL gesperrte Seiten werden nicht angezeigt.';
$lang['email_fail']            = 'PHP-Funktion "mail ()" fehlt oder ist deaktiviert. Die folgende E-Mail wurde nicht gesendet:';
$lang['currentns']             = 'Aktueller Namensraum';
$lang['searchresult']          = 'Suchergebnis';
$lang['plainhtml']             = 'Reines HTML';
$lang['wikimarkup']            = 'Wiki Markup';
$lang['page_nonexist_rev']     = 'Seite existierte nicht an der Stelle %s. Sie wurde an folgende Stelle erstellt: <a href="%s">%s</a>.';
$lang['unable_to_parse_date']  = 'Parameter "%s" kann nicht geparsed werden.';
$lang['email_signature_text']  = 'Diese E-Mail wurde erzeugt vom DokuWiki unter
@DOKUWIKIURL@';
